<?php

declare(strict_types=1);

namespace App\Dictionary\EHealthCard;

use App\Dictionary\Patient\IdentityType as PatientCardType;

/**
 * 电子健康卡 - 证件类型
 *
 * @see https://open.tengmed.com/openAccess/docs/develop#73
 */
enum CardType: int
{

    case RESIDENT_ID_CARD = 1;

    case RESIDENT_HOUSEHOLD_REGISTER = 2;

    case PASSPORT = 3;

    case OFFICER_ID_CARD = 4;

    case DRIVER_LICENSE = 5;

    case HK_MACAO_RESIDENT_PASS = 6;

    case TAIWAN_RESIDENT_PASS = 7;

    case BIRTH_CERTIFICATE = 8;

    case MEDICAL_INSURANCE_CARD = 9;

    case MEDICAL_CARD = 10;

    case ELECTRON_HEALTH_CARD = 11;

    case NEWBORN_CERTIFICATE = 12;

    case PERMANENT_RESIDENCE_PERMIT = 15;

    case OTHER = 99;

    /**
     * Label string
     */
    public function label(): string
    {
        return match ($this) {
            self::RESIDENT_ID_CARD => '居民身份证',
            self::RESIDENT_HOUSEHOLD_REGISTER => '居民户口簿',
            self::PASSPORT => '护照',
            self::OFFICER_ID_CARD => '军官证',
            self::DRIVER_LICENSE => '驾驶证',
            self::HK_MACAO_RESIDENT_PASS => '港澳居民来往内地通行证',
            self::TAIWAN_RESIDENT_PASS => '台湾居民来往内地通行证',
            self::BIRTH_CERTIFICATE => '出生医学证明',
            self::MEDICAL_INSURANCE_CARD => '医保卡',
            self::MEDICAL_CARD => '就诊卡',
            self::ELECTRON_HEALTH_CARD => '电子健康卡',
            self::NEWBORN_CERTIFICATE => '新生儿证件',
            self::PERMANENT_RESIDENCE_PERMIT => '外国人永久居住证',
            self::OTHER => '其他法定有效证件',
        };
    }

    /**
     * Patient Card Type To Electron Hath Card Type
     */
    public function patientCardTypeToEHathCardType(PatientCardType $card_type): CardType
    {
        return match ($card_type) {
            PatientCardType::ID_CARD_NO => self::RESIDENT_ID_CARD,
            PatientCardType::HMT_CARD_NO => self::HK_MACAO_RESIDENT_PASS,
            PatientCardType::PASSPORT => self::PASSPORT,
            PatientCardType::OFFICER_ID_CARD => self::OFFICER_ID_CARD
        };
    }
}
