<?php

declare(strict_types=1);

namespace App\Dictionary\EHealthCard;

/**
 * 电子健康卡 - 用卡环节
 *
 * @see https://open.tengmed.com/openAccess/docs/develop#74
 */
enum Scene: string
{
    case APPOINTMENT_REGISTRATION = '0101011';

    case TODAY_REGISTRATION = '0101012';

    case REGISTRATION_RECORD = '0101013';

    case SMART_GUIDANCE = '0101014';

    case OUTPATIENT_PAYMENT = '0101051';

    case OUTPATIENT_PAYMENT_RECORD = '0101052';

    case INPATIENT_RECHARGE = '0101056';

    case CHECK_REPORT_QUERY = '0101081';

    case TEST_REPORT_QUERY = '0101082';

    case INPATIENT_RECORD = '0101085';

    case BASIC_INFORMATION = '0101087';

    case ONLINE_CONSULTATION = '0201016';

    case QUEUE_NUMBER = '0201028';

    case APPOINTMENT_REGISTRATION_HEALTH_INSURANCE_PAYMENT = '0201074';

    case TODAY_REGISTRATION_HEALTH_INSURANCE_PAYMENT = '0201075';

    case OUTPATIENT_HEALTH_INSURANCE_PAYMENT = '0201076';

    case ONLINE_TEXT_CONSULTATION = '0301011';

    case ONLINE_VIDEO_CONSULTATION = '0301012';

    case TELEPHONE_CONSULTATION = '0301013';

    case BIND_HEALTH_CARD = '050100';

    case OTHER = '09000';

    /**
     * Label string
     */
    public function label(): string
    {
        return match ($this) {
            self::APPOINTMENT_REGISTRATION => '预约挂号',
            self::TODAY_REGISTRATION => '当日挂号',
            self::REGISTRATION_RECORD => '挂号记录',
            self::SMART_GUIDANCE => '智能导诊',
            self::OUTPATIENT_PAYMENT => '门诊缴费',
            self::OUTPATIENT_PAYMENT_RECORD => '门诊缴费记录',
            self::INPATIENT_RECHARGE => '住院充值',
            self::CHECK_REPORT_QUERY => '查（取）检查报告',
            self::TEST_REPORT_QUERY => '查（取）检验报告',
            self::INPATIENT_RECORD => '住院记录',
            self::BASIC_INFORMATION => '基本信息',
            self::ONLINE_CONSULTATION => '在线问诊',
            self::QUEUE_NUMBER => '排队取号',
            self::APPOINTMENT_REGISTRATION_HEALTH_INSURANCE_PAYMENT => '预约挂号医保支付',
            self::TODAY_REGISTRATION_HEALTH_INSURANCE_PAYMENT => '当日挂号医保支付',
            self::OUTPATIENT_HEALTH_INSURANCE_PAYMENT => '门诊费（药费）医保支付',
            self::ONLINE_TEXT_CONSULTATION => '图文咨询',
            self::ONLINE_VIDEO_CONSULTATION => '视频咨询',
            self::TELEPHONE_CONSULTATION => '电话咨询',
            self::BIND_HEALTH_CARD => '绑定健康卡',
            self::OTHER => '其他',
        };
    }
}
