<?php

declare(strict_types=1);

namespace App\Dictionary\SendMessage;

use App\Dictionary\WeChat\MiniProgram\OpenApi as MiniOpenApi;
use App\Dictionary\WeChat\Official\OpenApi as OfficialOpenApi;

/**
 * 推送微信消息类型
 */
enum Type: int
{
    case TEMPLATE = 1;

    case SINGLE_SUBSCRIBE = 2;

    case SUBSCRIBE = 3;

    case CUSTOM = 4;

    /**
     * Label string.
     *
     * @return string
     */
    public function label(): string
    {
        return match ($this) {
            self::TEMPLATE => '模板消息',
            self::SINGLE_SUBSCRIBE => '一次性订阅消息',
            self::SUBSCRIBE => '长期订阅消息',
            self::CUSTOM => '客服消息',
        };
    }

    /**
     * Get Open Api.
     *
     * @return OfficialOpenApi|MiniOpenApi
     */
    public function api(): OfficialOpenApi|MiniOpenApi
    {
        return match ($this) {
            self::TEMPLATE => OfficialOpenApi::SEND_TEMPLATE_MESSAGE,
            self::SINGLE_SUBSCRIBE,
            self::SUBSCRIBE => MiniOpenApi::SEND_SUBSCRIBE_MESSAGE,
            self::CUSTOM => OfficialOpenApi::SEND_CUSTOM_MESSAGE,
        };
    }
}
