<?php

declare(strict_types=1);

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Department extends Model
{
    use HasFactory;

    /**
     * @var string
     */
    protected $connection = 'mysql_admin';

    /**
     * @var string
     */
    protected $table = 'departments';

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'dept_id',
        'dept_name',
        'category_id',
        'icon',
        'introduction',
        'sort',
        'is_enable'
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'id' => 'integer',
        'category_id' => 'integer',
        'sort' => 'integer',
        'is_enable' => 'integer',
    ];

    /**
     * 科室分类
     * @return BelongsTo
     */
    public function departmentCategory(): BelongsTo
    {
        return $this->belongsTo(DepartmentCategory::class, 'category_id');
    }

    /**
     * 获取科室医生
     * @return HasMany
     */
    public function doctor(): HasMany
    {
        return $this->hasMany(Doctor::class, 'dept_id', 'dept_id');
    }
}
