<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class () extends Migration {

    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('orders', static function (Blueprint $table) {
            $table->id();
            $table->integer('relate_id')->default(0)->comment('关联订单表ID');
            $table->integer('relate_patient_id')->default(0)->comment('关联患者表ID');
            $table->string('order_id', 64)->unique()->comment('订单ID');
            $table->string('his_order_id', 64)->comment('his订单ID');
            $table->string('transaction_id', 64)->comment('交易平台单号');
            $table->unsignedTinyInteger('status')->index()->comment('订单状态 0未执行 1异常 2成功 3冲正 4失败');
            $table->unsignedTinyInteger('notify_status')->index()->comment('回调消息状态 0未收到 1已收到回调');
            $table->unsignedTinyInteger('type')->index()->comment('订单类型 1当天挂号 2预约挂号 3门诊缴费 4住院按金 5门诊预交金充值 6住院预交金充值 7门诊预交金退费 8住院预交金退费');
            $table->unsignedTinyInteger('pay_type')->index()->comment('支付类型 1聚合 2银联 3微信 4支付宝 5医保支付');
            $table->unsignedTinyInteger('pay_mode')->index()->comment('支付模式 1支付/充值 2退款');
            $table->integer('fee')->comment('总交易金额 分');
            $table->integer('reduce_fee')->comment('减免金额 分');
            $table->integer('self_fee')->comment('自费金额 分');
            $table->integer('refund_fee')->comment('累计退费金额 分');
            $table->string('open_id', 32)->index()->comment('openid');
            $table->string('patient_id', 20)->index()->comment('患者ID');
            $table->string('patient_name', 50)->comment('患者名称');
            $table->unsignedTinyInteger('source_id')->index()->comment('订单来源 1微信公众号 2微信小程序');
            $table->timestamp('payment_at')->nullable()->comment('支付时间');
            $table->timestamp('refunded_at')->nullable()->comment('退费时间');
            $table->timestamps();
            $table->engine = 'InnoDB';
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('orders');
    }
};
