<?php

declare(strict_types=1);

namespace UnifyPayment\Cores;

use UnifyPayment\Cores\Support\Logger;

/**
 * @method void emergency($message, array $context = array())
 * @method void alert($message, array $context = array())
 * @method void critical($message, array $context = array())
 * @method void error($message, array $context = array())
 * @method void warning($message, array $context = array())
 * @method void notice($message, array $context = array())
 * @method void info($message, array $context = array())
 * @method void debug($message, array $context = array())
 * @method void log($message, array $context = array())
 */
class Log extends Logger
{

    /**
     * Instance.
     *
     * @var Logger
     */
    private static Logger $instance;

    /**
     * Bootstrap.
     */
    private function __construct()
    {
    }

    /**
     * __call
     *
     * @param string $method
     * @param array  $parameters
     *
     * @return void
     */
    public function __call(string $method, array $parameters): void
    {
        call_user_func_array([self::getInstance(), $method], $parameters);
    }

    /**
     * __callStatic
     *
     * @param string $method
     * @param array  $parameters
     *
     * @return void
     */
    public static function __callStatic(string $method, array $parameters): void
    {
        forward_static_call_array([self::getInstance(), $method], $parameters);
    }

    /**
     * Get Log Instance
     *
     * @return Logger
     */
    public static function getInstance(): Logger
    {
        if (is_null(self::$instance)) {
            self::$instance = new Logger();
        }

        return self::$instance;
    }

    /**
     * Set Log Instance
     *
     * @param Logger $logger
     */
    public static function setInstance(Logger $logger): void
    {
        self::$instance = $logger;
    }
}