<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct QueryOrder.
 */
class QueryOrder
{
    use Arrayable;

    /**
     * @var string
     */
    public string $orderNo;

    /**
     * QueryOrder construct.
     *
     * @param string $orderNo
     */
    public function __construct(string $orderNo = '')
    {
        $this->setOrderNo($orderNo);
    }

    /**
     * Get orderNo value
     *
     * @return string|null
     */
    public function getOrderNo(): string
    {
        return $this->orderNo;
    }

    /**
     * Set orderNo value
     *
     * @param string $orderNo
     *
     * @return QueryOrder
     */
    public function setOrderNo(string $orderNo = ''): QueryOrder
    {
        // validation for constraint: string
        if (!is_string($orderNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderNo, true),
                    gettype($orderNo)
                ), __LINE__
            );
        }

        $this->orderNo = $orderNo;
        return $this;
    }
}