<?php

declare(strict_types=1);

namespace UnifyPayment\Mock;

class QueryOrderHandler extends ResponseHandler
{
    /**
     * @return array
     */
    public function success(): array
    {
        $channelId = 'FD00' . $this->faker->randomDigit();
        $status = $this->faker->randomElement(self::TRADE_STATE);

        $data = array_merge($this->getSuccessHeaderData('Create Success.'), [
            'response' => [
                'orderNo' => 'FD' . $channelId . $this->faker->time('YmdHis') . $this->faker->regexify('[0-9]{5}'),
                'payAccount' => $this->faker->email(),
                'transNo' => $this->faker->time('YmdHis') . $this->faker->regexify('[0-9]{10}'),
                'status' => $status,
                'statusDesc' => self::TRADE_STATE_DESC[$status],
                'amount' => $this->faker->randomFloat(2),
                'tag' => $this->faker->numerify('tag###'),
                'merchantId' => 'STZL' . $this->faker->time('Ymd'),
                'merchantName' => $this->faker->company(),
                'channelId' => $channelId,
                'channelName' => $this->faker->randomElement(['公众号支付', '小程序支付'])
            ]
        ]);

        return [
            self::SUCCESS_CODE,
            self::JSON_HEADER,
            json_encode($data, JSON_UNESCAPED_UNICODE)
        ];
    }

    /**
     * @return array
     */
    public function failure(): array
    {
        $data = $this->getFailureHeaderData($this->faker->sentence());

        return [
            self::FAILURE_CODE,
            self::JSON_HEADER,
            json_encode($data, JSON_UNESCAPED_UNICODE)
        ];
    }
}