<?php

declare(strict_types=1);

namespace UnifyPayment\Mock;

class RefundOrderHandler extends ResponseHandler
{
    /**
     * @return array
     */
    public function success(): array
    {
        $channelId = 'FD00' . $this->faker->randomDigit();
        $orderNo = 'FD' . $channelId . $this->faker->time('YmdHis') . $this->faker->regexify('[0-9]{5}');

        $data = array_merge($this->getSuccessHeaderData('Query Success.'), [
            'response' => [
                'orderNo' => $orderNo,
                'refundNo' => $orderNo . '_' . $this->faker->regexify('[0-9]{5}'),
                'refundAmount' => $this->faker->randomFloat(2),
                'refundTime' => $this->faker->time('Y-m-d H:i:s'),
                'merchantId' => 'STZL' . $this->faker->time('Ymd'),
                'merchantName' => $this->faker->company(),
                'channelId' => $channelId,
                'channelName' => $this->faker->randomElement(['公众号支付', '小程序支付'])
            ]
        ]);

        return [
            self::SUCCESS_CODE,
            self::JSON_HEADER,
            json_encode($data, JSON_UNESCAPED_UNICODE)
        ];
    }

    /**
     * @return array
     */
    public function failure(): array
    {
        $data = $this->getFailureHeaderData($this->faker->sentence());

        return [
            self::FAILURE_CODE,
            self::JSON_HEADER,
            json_encode($data, JSON_UNESCAPED_UNICODE)
        ];
    }
}